<?php defined('BASEPATH') OR exit('No direct script access allowed');

class Brcustomerfacemodel extends CI_Model {

    function __construct()
    {
        parent::__construct();
        date_default_timezone_set('Asia/Hong_Kong');
    }
    
    //added customerbodymodel function
      function getAll()
    {
        
        $this->db->from('brfaceoption');
        // $this->db->where(array('show' => 1));
        $this->db->where(array('delete_time' => NULL));
        // $this->db->order_by('rank');
        $this->db->order_by('display_order', 'asc');
        $query = $this->db->get();
        return $query->result();
    }
    function name_exists($name){
        $this->db->where('LOWER(name)', $name);
        $query = $this->db->get('brfaceoption');
        $this->db->where(array('delete_time' => NULL));
        if($query->num_rows() == 1){
            return false;
        } else {
            return true;
        }
    }
     function insertcustomerbody($inputdata){
            $this->db->trans_begin();
            $data = array(
            'display_order' => $inputdata['display_order'] ,
            'name' => $inputdata['name'] ,
            );
           date_default_timezone_set('Asia/Hong_Kong');
           $this->db->set('update_time', time(), FALSE);
           $this->db->set('create_time', time(), FALSE);
           $query=$this->db->insert('brfaceoption', $data);

           if ($this->db->trans_status() === FALSE){
                $this->db->trans_rollback();
                return false;
            }
            else{
                $this->db->trans_commit();
                return true;
            }
    }
    
     function getCustomerBody($id){
        $this->db->select("*");
        $this->db->from('brfaceoption');
        $this->db->where(array('delete_time' => NULL,'id' => $id));
        $query = $this->db->get();
        return $query->row();
    }
    function name_existsbyid($name,$id){
        $this->db->where('LOWER(name)', $name);
        $this->db->where('id!=', $id);
        $query = $this->db->get('brfaceoption');
        if($query->num_rows() == 1){
            return false;
        } else {
            return true;
        }
    }
     function updatebodylevel($inputdata){
        $this->db->trans_begin();
        $data = array(
            'display_order' => $inputdata['display_order'] ,
            'name' => $inputdata['name'] ,
            // 'consumeAmount' => $inputdata['consumeAmount'] ,
            // 'discount' => $inputdata['discount'] ,
            // 'discount_percent' => $inputdata['discount_percent'] ,
            // 'status' => 1 ,
            // 'display' => 0 ,// 0 stand for display, 1 stand for not display
            // 'deleted' => 0 , //0 stand for not deleted, 1 stand for deleted
            );
           date_default_timezone_set('Asia/Hong_Kong');
           $this->db->set('update_time', time(), FALSE);
            $this->db->where('id', $inputdata['id']);
           $query=$this->db->update('brfaceoption', $data);

           // return $query;
           
            if ($this->db->trans_status() === FALSE){
                $this->db->trans_rollback();
                return false;
            }
            else{
                $this->db->trans_commit();
                return true;
            }
    }
    function deleteAdmin($id){
        $this->db->trans_begin();
        $data = array(
            
            );
        date_default_timezone_set('Asia/Hong_Kong');
       // $this->db->set('deleted', 1, FALSE);
        $this->db->set('delete_time', time(), FALSE);
       $this->db->where('id', $id);
       $query=$this->db->update('brfaceoption', $data);

       // return $query;

            if ($this->db->trans_status() === FALSE){
                $this->db->trans_rollback();
                return false;
            }
            else{
                $this->db->trans_commit();
                return true;
            }

    }

    
    //end added customerbodymodel function
    function getLevelAll()
    {
        
        $this->db->from('brmemberLevel');
        // $this->db->where(array('show' => 1));
        $this->db->where(array('deleted' => 0));
        // $this->db->order_by('rank');
        $query = $this->db->get();
        return $query->result();
    }


    
    

    
   



    

    function getShopAll()
    {
        
        $this->db->from('bshop');
        // $this->db->where(array('show' => 1));
        $this->db->where(array('deleted' => 0));
        // $this->db->order_by('rank');
        $query = $this->db->get();
        return $query->result();
    }
    function shopcode_exists($code){
        $this->db->where('LOWER(shortcode)', $code);
        $query = $this->db->get('bshop');
        if($query->num_rows() == 1){
            return false;
        } else {
            return true;
        }
    }
    function insertShop($inputdata){
           $data = array(
            'shortcode' => $inputdata['shortcode'] ,
            'code' => $inputdata['code'] ,
            'name' => $inputdata['name'] ,
            'status' => 1 ,
            'display' => 0 ,// 0 stand for display, 1 stand for not display
            'deleted' => 0 , //0 stand for not deleted, 1 stand for deleted
            );
           date_default_timezone_set('UTC');
           $this->db->set('update_time', time(), FALSE);
           $this->db->set('create_time', time(), FALSE);
           $query=$this->db->insert('bshop', $data);

           return $query;
    }
     function getShopcode($id){
        $this->db->from('bshop');
        $this->db->where('id',$id);
        $shortcode=$this->db->get()->row()->shortcode;
        return $shortcode."0000";
    }
    function getSkinImprove(){
        //may be change the table name
        $this->db->from('mas_skin_improve');
        $this->db->order_by('id');
        $query = $this->db->get();
        return $query->result();
    }
    

    function getBannerAll()
    {
        
        $this->db->from('tblFolders');
        // $this->db->where(array('show' => 1));
        // $this->db->order_by('rank');
        $query = $this->db->get();
        return $query->result();
    }

    // function getAdmindata(){
    //     $this->db->select('id,login, fullName, update_time');
    //     $query = $this->db->get('adminUsers');
    //     return $query->result();
    // }
    // function record_count(){
    //     $this->db->select('id');
    //     $this->db->where('level1', '0');
    //     $this->db->where('level2', NULL);
    //     $query = $this->db->get('tblFolders');
    //     return $query->num_rows();
    // }
    // function count_all_folders(){
    //     $this->db->select('id');
    //     $query = $this->db->get('tblFolders');
    //     return $query->num_rows();    
    // }   
    // function getflodercount($id){
    //     $this->db->select('id');
    //     $this->db->where('level1', $id);
    //     // $this->db->where('level2!=', NULL);
    //     $query = $this->db->get('tblFolders');
    //     return $query->num_rows();    
    // }    

    // function getfolderdata($perpage,$page){
    //     $this->db->select('id,name,level1, update_time');
    //     $offset=$page* $perpage;
    //     $this->db->where('level1', 0);
    //     $this->db->limit($perpage, $offset);
    //     $query = $this->db->get('tblFolders');
    //     return $query->result();
    // }


    // function getlevel1data($id)
    // {
    //     $this->db->select('id,name,level1, update_time');
    //     $this->db->where('level1', $id);
    //     $this->db->where('level2', NULL);
    //     $query = $this->db->get('tblFolders');
    //     return $query->result();
    // }
    // function getlevel2data($id)
    // {
    //     $this->db->select('id,name,level1, update_time');
    //     $this->db->where('level2', $id);
    //     $this->db->where('level3', NULL);
    //     $query = $this->db->get('tblFolders');
    //     return $query->result();
    // }
    // function getlevel3data($id){
    //     $this->db->select('id,name,level1, update_time');
    //     $this->db->where('level3', $id);
    //     $this->db->where('level4', NULL);
    //     $query = $this->db->get('tblFolders');
    //     return $query->result();
    // }
    // function getlevel4data($id){
    //     $this->db->select('id,name,level1, update_time');
    //     $this->db->where('level4', $id);
    //     $this->db->where('level5', NULL);
    //     $query = $this->db->get('tblFolders');
    //     return $query->result();
    // }

    // //get all folder data for rightend
    // function getallfolderdata(){
    //     $this->db->select('id,name,level1,level2,level3,level4, update_time');
    //     $query = $this->db->get('tblFolders');
    //     return $query->result();
    // }    
    // function getalllevel1datainclude($id)
    // {
    //     $this->db->select('id,name,level1,level2,level3,level4, update_time');
    //     $this->db->where('level1', $id);
    //     $query = $this->db->get('tblFolders');
    //     return $query->result();
    // } 
    // function getalllevel2datainclude($id)
    // {
    //     $this->db->select('id,name,level1,level2,level3,level4, update_time');
    //     $this->db->where('level2', $id);
    //     $query = $this->db->get('tblFolders');
    //     return $query->result();
    // } 
    // function getalllevel3datainclude($id)
    // {
    //     $this->db->select('id,name,level1,level2,level3,level4, update_time');
    //     $this->db->where('level3', $id);
    //     $query = $this->db->get('tblFolders');
    //     return $query->result();
    // }    

    // //end get all folder data for rightend

    // function getAdmindateByid($id){
    //     $this->db->select('id,login, companyName,fullName,tel, update_time');
    //     $this->db->where('id', $id);
    //     $query = $this->db->get('tblFolders');
    //     return $query->result();
    // }

    
    // function getFolderName($id){
    //     $this->db->select('name');
    //     $this->db->where('id', $id);
    //     $query = $this->db->get('tblFolders');
    //     if ($query->num_rows() > 0) {
    //         // return $query->first_row();
    //          $row = $query->row(); 
    //         return $row->name;
    //     }
    //     return "";
    // }

    // function insertFolder($data){
    //     // 'inputadminname'=>$inputadminname,
    //     //         'inputloginname'=>$inputloginname,
    //     //         'inputPassword'=>$inputPassword,
    //     $data = array(
    //         'name' => $data['inputflodername'] ,
    //         'level1' => '0' ,
            
    //      );
    //      $this->db->set('update_time', 'NOW()', FALSE);
    //      $query=$this->db->insert('tblFolders', $data);
    //      return $query;
    // }
    // function insertLevelFolder($data){
    //     // 'inputadminname'=>$inputadminname,
    //     //         'inputloginname'=>$inputloginname,
    //     //         'inputPassword'=>$inputPassword,
    //     if($data['addlevel']==1){
    //         $data = array(
    //             'name' => $data['inputflodernamelevel'] ,
    //             'level1' => '0' ,
                
    //          );
    //     }
    //     if($data['addlevel']==2){
    //         $data = array(
    //             'name' => $data['inputflodernamelevel'] ,
    //             'level1' => $data['addlevelid'] ,
                
    //          );
    //     }
        
        
    //      $this->db->set('update_time', 'NOW()', FALSE);
    //      $query=$this->db->insert('tblFolders', $data);
    //      return $query;
    // }
    // function insertLevelOneFolder($name,$level){
    //     $data = array(
    //         'name' => $name ,
    //         'level1' => '0' ,
            
    //      );
    //      $this->db->set('update_time', 'NOW()', FALSE);
    //      $query=$this->db->insert('tblFolders', $data);
    //      return $query;
        
    // }
    // function insertLevelTwoFolder($name,$addlevel,$addlevelid){
    //     $data = array(
    //         'name' => $name ,
    //         'level1' => $addlevelid ,
            
    //      );
    //      $this->db->set('update_time', 'NOW()', FALSE);
    //      $query=$this->db->insert('tblFolders', $data);
    //      return $query;
    // }
    // function insertLevelThreeFolder($name,$addlevel,$addlevelid,$secondvalues){
    //     $data = array(
    //         'name' => $name ,
    //         'level1' => $addlevelid ,
    //         'level2' => $secondvalues ,
    //      );
    //      $this->db->set('update_time', 'NOW()', FALSE);
    //      $query=$this->db->insert('tblFolders', $data);
    //      return $query;
    // }

    // function insertLevelFourFolder($name,$addlevel,$addlevelid,$thirdvalues){
    //     $secondlevelid=$this->findLevelThreeid($thirdvalues);
    //     $data = array(
    //         'name' => $name ,
    //         'level1' => $addlevelid ,
    //         'level2' => $secondlevelid ,
    //         'level3' => $thirdvalues ,
    //      );
    //      $this->db->set('update_time', 'NOW()', FALSE);
    //      $query=$this->db->insert('tblFolders', $data);
    //      return $query;
    // }
    // function insertLevelMonthWeekFolder($values,$addlevel,$addlevelid,$secondvalues){
    //     $montharray = array("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep","Oct","Nov","Dec");
    //     $weekarray =  array("Week 1", "Week 2", "Week 3", "Week 4", "Week 5");
    //     foreach($montharray as $month){
    //         if($this->folder_levelThreeexists(strtolower($month),$addlevel,$addlevelid,$secondvalues)==true){
    //              $data = array(
    //             'name' =>  $month ,
    //             'level1' => $addlevelid ,
    //             'level2' => $secondvalues ,
    //          );
    //          $this->db->set('update_time', 'NOW()', FALSE);
    //          $query=$this->db->insert('tblFolders', $data);
    //          $lastinsertid = $this->db->insert_id();
    //          foreach ($weekarray as $week) {

    //              $data = array(
    //             'name' =>  $week ,
    //             'level1' => $addlevelid ,
    //             'level2' => $secondvalues ,
    //             'level3' => $lastinsertid ,
    //              );
    //             $this->db->set('update_time', 'NOW()', FALSE);
    //              $query=$this->db->insert('tblFolders', $data);
    //          }

    //         }//if(folder_levelThreeexists($month,$addlevel,$addlevelid,$secondvalues)==false){
    //     }//foreach($montharray as $month){
    //     return $query;
    // }

    // function updateAdmin($input){
    //     // 'inputadminname'=>$inputadminname,
    //     //         'inputloginname'=>$inputloginname,
    //     //         'inputPassword'=>$inputPassword,
        
    //     if(empty($input['inputPassword'])){
    //         $data = array(
    //             'login' => $input['inputloginname'] ,
    //             'companyName' => $input['inputcompanynameedit'],
    //             'fullName' => $input['inputfullnameedit'], 
    //             'tel' => $input['inputteledit']  
                
    //          );
    //     }
    //     else{
    //         $data = array(
    //             'login' => $input['inputloginname'] ,
    //             'companyName' => $input['inputcompanynameedit'],
    //             'fullName' => $input['inputfullnameedit'], 
    //             'tel' => $input['inputteledit']  ,
    //             'pwd' => $input['inputPassword'] 
    //          );
    //     }
        
    //      $this->db->set('update_time', 'NOW()', FALSE);

    //      $this->db->where('id', $input['id']);
    //      $query=$this->db->update('tblFolders', $data);
    //      return $query;
    // }

    // function deleteAdmin($id){
    //     $this->db->where('id', $id);
    //     $query = $this->db->get('tblFolders');
    //     $row = $query->row(); 

    //     //check level of delete
    //     $deleteLevel=0;
    //     if($row->level4 ==NULL  && $row->level3!=NULL){
    //         $deleteLevel=4;
    //     }
    //     if($row->level3 ==NULL  && $row->level2!=NULL){
    //         $deleteLevel=3;
    //     }
    //     if($row->level2 ==NULL  && $row->level1!=NULL && $row->level1!=0){
    //         $deleteLevel=2;
    //     }
    //     if( $row->level1==0){
    //         $deleteLevel=1;
    //     }

    //     //end check level of delete
    //     if($deleteLevel==4){
    //         $this->db->where('id', $id);
    //         $query = $this->db->get('tblFolders');
    //         if($query->num_rows() != 0){
    //             $this->db->where('id', $id);
    //             $query=$this->db->delete('tblFolders');
    //         }
    //     }
    //     if($deleteLevel==3){

    //         $this->db->where('level3 ',$id);
    //         $query = $this->db->get('tblFolders');
    //         if($query->num_rows() != 0){
    //             $this->db->where('level3', $id);
    //              $query=$this->db->delete('tblFolders');
    //         }

    //         $this->db->where('id', $id);
    //         $query = $this->db->get('tblFolders');
    //         if($query->num_rows() != 0){
    //             $this->db->where('id', $id);
    //             $query=$this->db->delete('tblFolders');
    //         }
    //     }
    //     if($deleteLevel==2){
    //         $this->db->where('level2 ',$id);
    //         $query = $this->db->get('tblFolders');
    //         if($query->num_rows() != 0){
    //             $this->db->where('level2', $id);
    //             $query=$this->db->delete('tblFolders');
    //         }

    //         $this->db->where('id', $id);
    //         $query = $this->db->get('tblFolders');
    //         if($query->num_rows() != 0){
    //             $this->db->where('id', $id);
    //             $query=$this->db->delete('tblFolders');
    //         }
    //     }
    //     if($deleteLevel==1){
    //         $this->db->where('level1 ',$id);
    //         $query = $this->db->get('tblFolders');
    //         if($query->num_rows() != 0){
    //             $this->db->where('level1', $id);
    //             $query=$this->db->delete('tblFolders');
    //         }

    //         $this->db->where('id', $id);
    //         $query = $this->db->get('tblFolders');
    //         if($query->num_rows() != 0){
    //             $this->db->where('id', $id);
    //             $query=$this->db->delete('tblFolders');
    //         }
    //     }

        
    //     return $query;
    // }

    // function folder_exists($foldername){
    //     // $this->db->from('adminUsers');
    //     $this->db->where('LOWER(name)', $foldername);
    //     $this->db->where('LOWER(name)', $foldername);
    //     $query = $this->db->get('tblFolders');
    //     if($query->num_rows() == 1){
    //         return false;
    //     } else {
    //         return true;
    //     }
    // }

    // function folder_levelOneexists($foldername){
    //     // $this->db->from('adminUsers');
    //     $this->db->where('LOWER(name)', $foldername);
    //     $this->db->where('level1', '0');
    //     $query = $this->db->get('tblFolders');
    //     if($query->num_rows() == 1){
    //         return false;
    //     } else {
    //         return true;
    //     }
    // }

    // function folder_levelTwoexists($foldername,$level,$id){
    //     $this->db->where('LOWER(name)', $foldername);
    //     $this->db->where('level1', $id);
    //     $query = $this->db->get('tblFolders');
    //     if($query->num_rows() == 1){
    //         return false;
    //     } else {
    //         return true;
    //     }
    // }
    // function folder_levelThreeexists($foldername,$level,$id,$secondllevelid){
    //     $this->db->where('LOWER(name)', $foldername);
    //     $this->db->where('level1', $id);
    //     $this->db->where('level2', $secondllevelid);
    //     $query = $this->db->get('tblFolders');
    //     if($query->num_rows() == 1){
    //         return false;
    //     } else {
    //         return true;
    //     }
    // }
    // function folder_levelFourexists($foldername,$level,$id,$thirdllevelid){
    //     $secondlevelid=$this->findLevelThreeid($thirdllevelid);
    //     $this->db->where('LOWER(name)', $foldername);
    //     $this->db->where('level1', $id);
    //     $this->db->where('level2', $secondlevelid);
    //     $this->db->where('level3', $thirdllevelid);
    //     $query = $this->db->get('tblFolders');
    //     if($query->num_rows() == 1){
    //         return false;
    //     } else {
    //         return true;
    //     }

    // }

    // function folder_levelTwoMonthWeekexists($values,$addlevel,$addlevelid,$secondvalues){
    //     $montharray = array("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep","Oct","Nov","Dec");
    //     foreach($montharray as $month){
    //         $this->db->select("id");
    //         $this->db->where('name', $month);
    //         $this->db->where('level1', $addlevelid);
    //         $this->db->where('level2', NULL);
    //         $query = $this->db->get('tblFolders');
    //         if($query->num_rows() == 1){
    //             return false;
    //             //check week    
                

    //             //end check week

    //         } else {

    //         }
    //     }
        
    //     return true;
    // }

    // function checkleveltwoid($secondlevelid){
    //     $this->db->where('id', $secondlevelid);
    //     $this->db->where('level1 !=',0);
    //     $this->db->where('level2 ', NULL);
    //     $query = $this->db->get('tblFolders');
    //     if($query->num_rows() == 1){
    //         return false;
    //     } else {
    //         return true;
    //     }
    // }

    // function checklevelthreeid($thirdllevelid){
    //     $this->db->where('id', $thirdllevelid);
    //     $this->db->where('level2 !=', NULL);
    //     $this->db->where('level3 ', NULL);
    //     $query = $this->db->get('tblFolders');
    //     if($query->num_rows() == 1){
    //         return false;
    //     } else {
    //         return true;
    //     }
    // }
    // function findLevelThreeid($thirdllevelid){
    //     $this->db->select("level2");
    //     $this->db->where('id', $thirdllevelid);
    //     $this->db->from('tblFolders');
    //     $query = $this->db->get();
    //     // $ret = $query->row();
    //     // return $ret->level2;
    //     if ($query->num_rows() > 0)
    //     {
    //         $row = $query->row(); 
    //         return $row->level2;
    //     }
    //     return NULL;
    // }

    // function login_existsbyid($loginname,$id){
    //     // $this->db->from('adminUsers');
    //     $this->db->where('LOWER(login)', $loginname);
    //     $this->db->where('id!=', $id);
    //     $query = $this->db->get('tblFolders');
    //     if($query->num_rows() == 1){
    //         return false;
    //     } else {
    //         return true;
    //     }
    // }
   

    // function admin_exists($loginname){
    //     // $this->db->from('adminUsers');
    //     $this->db->where('LOWER(fullName)', $loginname);
    //     $query = $this->db->get('tblFolders');
    //     if($query->num_rows() == 1){
    //         return false;
    //     } else {
    //         return true;
    //     }
    // }

    // function admin_existsbyid($loginname,$id){
    //     // $this->db->from('adminUsers');
    //     $this->db->where('LOWER(fullName)', $loginname);
    //     $this->db->where('id!=', $id);
    //     $query = $this->db->get('tblFolders');
    //     if($query->num_rows() == 1){
    //         return false;
    //     } else {
    //         return true;
    //     }
    // }


    // //process login
    // function check(){
    //     $userName =  $this->input->post('userName');
    //     $password =  $this->input->post('password');

    //     $this->db->where('login',$userName);
    //     $this->db->where('pwd',$password);
    //     // $this->db->where('user_active','yes');
    //     return $this->db->get('tblFolders')->row_array();
    // }


    // function processLogin($userName=NULL,$password){



    //     $this->db->select("id,login,fullName");
    //     $whereCondition = $array = array('login' =>$userName,'pwd'=>$password);
    //     $this->db->where($whereCondition);
    //     $this->db->from('tblFolders');
    //     $query = $this->db->get();
    //     return $query;
    // }//function processLogin(){
    // //end process login

    // function buildTopMenuItem()
    // {
    //     // $menu = array();
        
    //     // $result = $this->getSectionAll();
    //     // foreach ($result as $row)
    //     // {
    //     //     $menu[] = array(
    //     //         'name_zh' => $row->cp_name,
    //     //         'name_cn' => $row->sp_name,
    //     //         'name_en' => $row->ep_name,
    //     //         'link' => $row->link
    //     //     );
    //     // }
    //     // return $menu;
        
    // }
}